"use strict";

var _enzyme = require("enzyme");

var _react = _interopRequireDefault(require("react"));

var _BootstrapProvider = _interopRequireDefault(require("@bootstrap-styled/provider/lib/BootstrapProvider"));

var _OffsetNav = _interopRequireWildcard(require("../OffsetNav"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Testing our OffsetNav component
 */
var children = _react.default.createElement("h1", null, "Test");

describe('<OffsetNav />', function () {
  var theme;
  var props;
  beforeEach(function () {
    theme = _OffsetNav.defaultProps.theme; // eslint-disable-line prefer-destructuring

    props = Object.assign(_OffsetNav.defaultProps, {
      children: children,
      active: false,
      dismiss: jest.fn(),
      bgColor: null,
      top: null,
      show: null,
      right: false,
      push: false
    });
  });
  it('should render an OffsetNav', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_OffsetNav.default, props)));
    expect(renderedComponent.find('OffsetNav').length).toEqual(1);
  });
  it('should render an OffsetNav with an activable active prop', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_OffsetNav.default, Object.assign(props, {
      active: true
    }))));
    expect(renderedComponent.find('OffsetNav').props().active).toEqual(true);
  });
  it('should render an OffsetNav with a Close Button', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_OffsetNav.default, Object.assign(props, {
      menuClose: true
    }))));
    expect(renderedComponent.find('Close').length).toEqual(1);
  });
  it('should render an OffsetNav with a Close Button that calls an onDismiss function', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_OffsetNav.default, Object.assign(props, {
      menuClose: true
    }))));
    var close = renderedComponent.find('Close');
    close.simulate('click');
    expect(props.dismiss).toHaveBeenCalled();
  });
  it('should render an OffsetNav with a bgColor props', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_OffsetNav.default, Object.assign(props, {
      bgColor: 'primary'
    }))));
    expect(renderedComponent.find('OffsetNav').props().bgColor).toEqual('primary');
  });
  it('should render an OffsetNav with a right props', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_OffsetNav.default, Object.assign(props, {
      right: true
    }))));
    expect(renderedComponent.find('OffsetNav').props().right).toBe(true);
  });
  it('should render an OffsetNav with a animation-push props', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_OffsetNav.default, Object.assign(props, {
      push: true
    }))));
    expect(renderedComponent.find('OffsetNav').props().push).toBe(true);
  });
  it('should render an OffsetNav with a show props', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_OffsetNav.default, Object.assign(props, {
      show: 'md'
    }))));
    expect(renderedComponent.find('OffsetNav').props().show).toEqual('md');
  });
});